% Auto-generated chapter 49 for nasai
% Hadiths in this chapter: 49

\hadithdefcmd{nasai}{5379}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ آدَمَ بْنِ سُلَيْمَانَ، عَنِ ابْنِ الْمُبَارَكِ، عَنْ سُفْيَانَ بْنِ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَمْرِو بْنِ أَوْسٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ الْمُقْسِطِينَ عِنْدَ اللَّهِ تَعَالَى عَلَى مَنَابِرَ مِنْ نُورٍ عَلَى يَمِينِ الرَّحْمَنِ الَّذِينَ يَعْدِلُونَ فِي حُكْمِهِمْ وَأَهْلِيهِمْ وَمَا وَلُوا ‏"‏‏.‏ قَالَ مُحَمَّدٌ فِي حَدِيثِهِ ‏"‏ وَكِلْتَا يَدَيْهِ يَمِينٌ ‏"‏‏.‏\hadithno{5379}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah bin 'Amr bin Al-'As that:The Prophet [SAW] said: "Those who are just and fair will be with Allah, Most High, on thrones of light, at the right hand of the Most Merciful, those who are just in their rulings and in their dealings with their families and those of whom they are in charge." Muhammad (one of the narrators) said in his Hadith: "And both of His hands are right hands}}
\hadithdefcmd{nasai}{5380}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عُبَيْدِ اللَّهِ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ سَبْعَةٌ يُظِلُّهُمُ اللَّهُ عَزَّ وَجَلَّ يَوْمَ الْقِيَامَةِ يَوْمَ لاَ ظِلَّ إِلاَّ ظِلُّهُ إِمَامٌ عَادِلٌ وَشَابٌّ نَشَأَ فِي عِبَادَةِ اللَّهِ عَزَّ وَجَلَّ وَرَجُلٌ ذَكَرَ اللَّهَ فِي خَلاَءٍ فَفَاضَتْ عَيْنَاهُ وَرَجُلٌ كَانَ قَلْبُهُ مُعَلَّقًا فِي الْمَسْجِدِ وَرَجُلاَنِ تَحَابَّا فِي اللَّهِ عَزَّ وَجَلَّ وَرَجُلٌ دَعَتْهُ امْرَأَةٌ ذَاتُ مَنْصِبٍ وَجَمَالٍ إِلَى نَفْسِهَا فَقَالَ إِنِّي أَخَافُ اللَّهَ عَزَّ وَجَلَّ وَرَجُلٌ تَصَدَّقَ بِصَدَقَةٍ فَأَخْفَاهَا حَتَّى لاَ تَعْلَمَ شِمَالُهُ مَا صَنَعَتْ يَمِينُهُ ‏"‏‏.‏\hadithno{5380}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that :The Messenger of Allah [SAW] said: "There are seven whom Allah, the Mighty and Sublime, will shade with His shade on the Day of Resurrection, the Day when there will be no shade but His: A just ruler, a young man who grows up worshipping Allah, the Mighty and Sublime; a man who remembers Allah when he is alone and his eyes flow (with tears); a man whose heart is attached to the Masjid; two men who love each other for the sake of Allah, the Mighty and Sublime; a man who is called (to commit sin) by a woman of high status and beauty, but he says: 'I fear Allah'; and a man who gives charity and conceals it, so that his left hand does not know what his right hand is doing}}
\hadithdefcmd{nasai}{5381}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنْ سُفْيَانَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي بَكْرِ، ‏\{‏بْنِ‏\}‏ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا حَكَمَ الْحَاكِمُ فَاجْتَهَدَ فَأَصَابَ فَلَهُ أَجْرَانِ وَإِذَا اجْتَهَدَ فَأَخْطَأَ فَلَهُ أَجْرٌ ‏"‏‏.‏\hadithno{5381}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said: 'If a judge passes judgment and strives to reach the right conclusion and gets it right, he will have two rewards; if he strives to reach the right conclusion but gets it wrong, he will still have one reward}}
\hadithdefcmd{nasai}{5382}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا عُمَرُ بْنُ عَلِيٍّ، عَنْ أَبِي عُمَيْسٍ، عَنْ سَعِيدِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، عَنْ أَبِي مُوسَى، قَالَ أَتَانِي نَاسٌ مِنَ الأَشْعَرِيِّينَ فَقَالُوا اذْهَبْ مَعَنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِنَّ لَنَا حَاجَةً‏.‏ فَذَهَبْتُ مَعَهُمْ فَقَالُوا يَا رَسُولَ اللَّهِ اسْتَعِنْ بِنَا فِي عَمَلِكَ‏.‏ قَالَ أَبُو مُوسَى فَاعْتَذَرْتُ مِمَّا قَالُوا وَأَخْبَرْتُ أَنِّي لاَ أَدْرِي مَا حَاجَتُهُمْ فَصَدَّقَنِي وَعَذَرَنِي‏.‏ فَقَالَ ‏ "‏ إِنَّا لاَ نَسْتَعِينُ فِي عَمَلِنَا بِمَنْ سَأَلَنَا ‏"‏‏.‏\hadithno{5382}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Musa said:"Some people from among the Ash'aris came to me and said: 'Go with us to the Messenger of Allah [SAW], for we have something to ask him.' So I went with them, and they said: 'O Messenger of Allah, use us to do your work.'" Abu Musa said: "I apologized for what they said, and I told him that I did not know what they were going to ask. He believed me and excused me, and said: 'We do not appoint for our work anyone who asks for that}}
\hadithdefcmd{nasai}{5383}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسًا، يُحَدِّثُ عَنْ أُسَيْدِ بْنِ حُضَيْرٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ جَاءَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ أَلاَ تَسْتَعْمِلْنِي كَمَا اسْتَعْمَلْتَ فُلاَنًا قَالَ ‏ "‏ إِنَّكُمْ سَتَلْقَوْنَ بَعْدِي أَثَرَةً فَاصْبِرُوا حَتَّى تَلْقَوْنِي عَلَى الْحَوْضِ ‏"‏‏.‏\hadithno{5383}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Usaid bin Hudair that:A man from among the Ansar came to the Messenger of Allah [SAW] and said: "Will you not appoint me as you appointed so-and-so?" He said: "You will encounter selfishness after I am gone, so be patient until you meet me at the cistern (Al-Hawd)}}
\hadithdefcmd{nasai}{5384}{أَخْبَرَنَا مُجَاهِدُ بْنُ مُوسَى، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، ح وَأَنْبَأَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، عَنِ الْحَسَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَسْأَلِ الإِمَارَةَ فَإِنَّكَ إِنْ أُعْطِيتَهَا عَنْ مَسْأَلَةٍ وُكِلْتَ إِلَيْهَا وَإِنْ أُعْطِيتَهَا عَنْ غَيْرِ مَسْأَلَةٍ أُعِنْتَ عَلَيْهَا ‏"‏‏.‏\hadithno{5384}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdur-Rahman bin Samurah said:"The Messenger of Allah [SAW] said: 'Do not ask for governorship. For if it is given to you because of asking, you will be left to your own devices, but if it is given to you without asking, you will be helped (by Allah)}}
\hadithdefcmd{nasai}{5385}{حَدَّثَنَا مُحَمَّدُ بْنُ آدَمَ بْنِ سُلَيْمَانَ، عَنِ ابْنِ الْمُبَارَكِ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّكُمْ سَتَحْرِصُونَ عَلَى الإِمَارَةِ وَإِنَّهَا سَتَكُونُ نَدَامَةً وَحَسْرَةً يَوْمَ الْقِيَامَةِ فَنِعْمَتِ الْمُرْضِعَةُ وَبِئْسَتِ الْفَاطِمَةُ ‏"‏‏.‏\hadithno{5385}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that :The Prophet [SAW] said: "You will be keen for governorship but it will be regret and loss on the Day of Resurrection. What a good position it is when they are alive, but how miserable their state when they die (and leave it behind)}}
\hadithdefcmd{nasai}{5386}{أَخْبَرَنَا الْحَسَنُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي ابْنُ أَبِي مُلَيْكَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، أَخْبَرَهُ أَنَّهُ، قَدِمَ رَكْبٌ مِنْ بَنِي تَمِيمٍ عَلَى النَّبِيِّ صلى الله عليه وسلم قَالَ أَبُو بَكْرٍ أَمِّرِ الْقَعْقَاعَ بْنَ مَعْبَدٍ‏.‏ وَقَالَ عُمَرُ رضى الله عنه بَلْ أَمِّرِ الأَقْرَعَ بْنَ حَابِسٍ‏.‏ فَتَمَارَيَا حَتَّى ارْتَفَعَتْ أَصْوَاتُهُمَا فَنَزَلَتْ فِي ذَلِكَ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تُقَدِّمُوا بَيْنَ يَدَىِ اللَّهِ وَرَسُولِهِ‏\}‏ حَتَّى انْقَضَتِ الآيَةُ ‏\{‏وَلَوْ أَنَّهُمْ صَبَرُوا حَتَّى تَخْرُجَ إِلَيْهِمْ لَكَانَ خَيْرًا لَهُمْ‏\}‏‏.‏\hadithno{5386}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abdullah bin Az-Zubair narrated that:A group from Banu Tamim came to the Prophet [SAW]. Abu Bakr said: "Appoint Al-Qa'qa' bin Ma'bad (as commander or governor)," and 'Umar said: "No, (appoint) Al-Aqra' bin Habis." They argued until they began to raise their voices, then the words were revealed: "O you who believe! Make not (a decision) in advance before Allah and His Messenger..." until the end of the Verse: "And if they had patience till you could come out to them, it would have been better for them}}
\hadithdefcmd{nasai}{5387}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا يَزِيدُ، وَهُوَ ابْنُ الْمِقْدَامِ بْنِ شُرَيْحٍ ‏\{‏عَنْ أَبِيهِ،‏\}‏ عَنْ شُرَيْحِ بْنِ هَانِئٍ، عَنْ أَبِيهِ، هَانِئٍ أَنَّهُ لَمَّا وَفَدَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم سَمِعَهُ وَهُمْ يَكْنُونَ هَانِئًا أَبَا الْحَكَمِ فَدَعَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهُ ‏"‏ إِنَّ اللَّهَ هُوَ الْحَكَمُ وَإِلَيْهِ الْحُكْمُ فَلِمَ تُكَنَّى أَبَا الْحَكَمِ ‏"‏‏.‏ فَقَالَ إِنَّ قَوْمِي إِذَا اخْتَلَفُوا فِي شَىْءٍ أَتَوْنِي فَحَكَمْتُ بَيْنَهُمْ فَرَضِيَ كِلاَ الْفَرِيقَيْنِ‏.‏ قَالَ ‏"‏ مَا أَحْسَنَ مِنْ هَذَا فَمَا لَكَ مِنَ الْوُلْدِ ‏"‏‏.‏ قَالَ لِي شُرَيْحٌ وَعَبْدُ اللَّهِ وَمُسْلِمٌ‏.‏ قَالَ ‏"‏ فَمَنْ أَكْبَرُهُمْ ‏"‏‏.‏ قَالَ شُرَيْحٌ‏.‏ قَالَ ‏"‏ فَأَنْتَ أَبُو شُرَيْحٍ ‏"‏‏.‏ فَدَعَا لَهُ وَلِوَلَدِهِ‏.‏\hadithno{5387}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Shuraih bin Hani' from his father, that:When he came to the Messenger of Allah [SAW] and he heard them calling Hani' by the nickname of Abu Al-Hakam, the Messenger of Allah [SAW] called him and said to him: "Allah is Al-Hakam (the Judge) and judgment is His. Why are you known as Abu Al-Hakam?" He said: "If my people differ concerning something, they come to me, and I pass judgment among them, and both sides accept it." He said: "How good this is. Do you have any children?" He said: "I have Shuraih, and 'Abdullah, and Muslim." He said: "Who is the eldest of them?" He said: "Shuraih." He said: "Then you are Abu Shuraih," and he supplicated for him and his son}}
\hadithdefcmd{nasai}{5388}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، قَالَ حَدَّثَنَا حُمَيْدٌ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، قَالَ عَصَمَنِي اللَّهُ بِشَىْءٍ سَمِعْتُهُ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم لَمَّا هَلَكَ كِسْرَى قَالَ ‏"‏ مَنِ اسْتَخْلَفُوا ‏"‏‏.‏ قَالُوا بِنْتَهُ‏.‏ قَالَ ‏"‏ لَنْ يُفْلِحَ قَوْمٌ وَلَّوْا أَمْرَهُمُ امْرَأَةً ‏"‏‏.‏\hadithno{5388}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Bakrah said:"Allah protected me with something that I heard from the Messenger of Allah [SAW]. When Chosroes died, he said: 'Whom have they appointed as his successor?' They said: 'His daughter.' He said: 'No people will ever prosper who entrust their leadership to a woman}}
\hadithdefcmd{nasai}{5389}{أَخْبَرَنَا مُحَمَّدُ بْنُ هَاشِمٍ، عَنِ الْوَلِيدِ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ الْفَضْلِ بْنِ عَبَّاسٍ، أَنَّهُ كَانَ رَدِيفَ رَسُولِ اللَّهِ صلى الله عليه وسلم غَدَاةَ النَّحْرِ فَأَتَتْهُ امْرَأَةٌ مِنْ خَثْعَمٍ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ فَرِيضَةَ اللَّهِ عَزَّ وَجَلَّ فِي الْحَجِّ عَلَى عِبَادِهِ أَدْرَكَتْ أَبِي شَيْخًا كَبِيرًا لاَ يَسْتَطِيعُ أَنْ يَرْكَبَ إِلاَّ مُعْتَرِضًا أَفَأَحُجُّ عَنْهُ قَالَ ‏ "‏ نَعَمْ حُجِّي عَنْهُ فَإِنَّهُ لَوْ كَانَ عَلَيْهِ دَيْنٌ قَضَيْتِيهِ ‏"‏‏.‏\hadithno{5389}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Al-Fadl bin 'Abbas that:He was riding behind the Messenger of Allah [SAW] on the morning of the Day of Sacrifice, when a woman from Khath'am came to him and said: "O Messenger of Allah, the command of Allah, the Mighty and Sublime, to His slaves to perform Hajj has come while my father is an old man and cannot ride unless he is tied crossways on a mount; can I perform Hajj on his behalf?" He said: "Yes, perform Hajj on his behalf, for if he owed a debt you would pay it off for him}}
\hadithdefcmd{nasai}{5390}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، قَالَ أَخْبَرَنِي ابْنُ شِهَابٍ، ح وَأَخْبَرَنِي مَحْمُودُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا عُمَرُ، عَنِ الأَوْزَاعِيِّ، حَدَّثَنِي الزُّهْرِيُّ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ ابْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّ امْرَأَةً مِنْ خَثْعَمٍ اسْتَفْتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم وَالْفَضْلُ رَدِيفُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ فَرِيضَةَ اللَّهِ عَزَّ وَجَلَّ فِي الْحَجِّ عَلَى عِبَادِهِ أَدْرَكَتْ أَبِي شَيْخًا كَبِيرًا لاَ يَسْتَطِيعُ أَنْ يَسْتَوِيَ عَلَى الرَّاحِلَةِ فَهَلْ يُجْزِئُ قَالَ مَحْمُودٌ فَهَلْ يَقْضِي - أَنْ أَحُجَّ عَنْهُ فَقَالَ لَهَا ‏ "‏ نَعَمْ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَقَدْ رَوَى هَذَا الْحَدِيثَ غَيْرُ وَاحِدٍ عَنِ الزُّهْرِيِّ فَلَمْ يَذْكُرْ فِيهِ مَا ذَكَرَ الْوَلِيدُ بْنُ مُسْلِمٍ‏.‏\hadithno{5390}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Sulaiman bin Yasar that Ibn 'Abbas told him:"A woman from Khath'am asked the Messenger of Allah [SAW] a question when Al-Fadl was riding behind the Messenger of Allah [SAW]. She said: 'O Messenger of Allah, the command of Allah, the Mighty and Sublime, to His slaves to perform Hajj has come while my father is an old man, he cannot sit upright in the saddle. Will it suffice if I perform Hajj on his behalf?' He said: 'Yes}}
\hadithdefcmd{nasai}{5391}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ كَانَ الْفَضْلُ بْنُ عَبَّاسٍ رَدِيفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَاءَتْهُ امْرَأَةٌ مِنْ خَثْعَمٍ تَسْتَفْتِيهِ فَجَعَلَ الْفَضْلُ يَنْظُرُ إِلَيْهَا وَتَنْظُرُ إِلَيْهِ وَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْرِفُ وَجْهَ الْفَضْلِ إِلَى الشِّقِّ الآخَرِ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ فَرِيضَةَ اللَّهِ عَزَّ وَجَلَّ عَلَى عِبَادِهِ فِي الْحَجِّ أَدْرَكَتْ أَبِي شَيْخًا كَبِيرًا لاَ يَسْتَطِيعُ أَنْ يَثْبُتَ عَلَى الرَّاحِلَةِ أَفَأَحُجُّ عَنْهُ قَالَ ‏ "‏ نَعَمْ ‏"‏‏.‏ وَذَلِكَ فِي حَجَّةِ الْوَدَاعِ‏.‏\hadithno{5391}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Abbas said:"Al-Fadl bin 'Abbas was riding behind the Messenger of Allah [SAW] when a woman from Khath'am came to ask him a question. Al-Fadl started looking at her, and she at him, and the Messenger of Allah [SAW] turned the face of Al-Fadl the other way. She said: 'O Messenger of Allah, the command of Allah, the Mighty and Sublime, to His slaves to perform Hajj has come while my father is an old man, and he cannot sit firmly in the saddle; can I perform Hajj on his behalf?' He said: 'Yes.' That was during the Farewell Pilgrimage}}
\hadithdefcmd{nasai}{5392}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنِي أَبِي، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، أَنَّ سُلَيْمَانَ بْنَ يَسَارٍ، أَخْبَرَهُ أَنَّ ابْنَ عَبَّاسٍ أَخْبَرَهُ أَنَّ امْرَأَةً مِنْ خَثْعَمٍ قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ فَرِيضَةَ اللَّهِ عَزَّ وَجَلَّ فِي الْحَجِّ عَلَى عِبَادِهِ أَدْرَكَتْ أَبِي شَيْخًا كَبِيرًا لاَ يَسْتَوِي عَلَى الرَّاحِلَةِ فَهَلْ يَقْضِي عَنْهُ أَنْ أَحُجَّ عَنْهُ قَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَعَمْ ‏"‏‏.‏ فَأَخَذَ الْفَضْلُ يَلْتَفِتُ إِلَيْهَا - وَكَانَتِ امْرَأَةً حَسْنَاءَ - وَأَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْفَضْلَ فَحَوَّلَ وَجْهَهُ مِنَ الشِّقِّ الآخَرِ‏.‏\hadithno{5392}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Shihab that Sulaiman bin Yasar told him that Ibn 'Abbas told him that:A woman from Khath'am said: "O Messenger of Allah, the command of Allah, the Mighty and Sublime, to His slaves to perform Hajj has come while my father is an old man, and he cannot sit upright in the saddle. Will it discharge his duty if I perform Hajj on his behalf?" The Messenger of Allah [SAW] said to her: "Yes." Al-Fadl starting turning toward her, for she was a beautiful woman, and the Messenger of Allah [SAW] turned Al-Fadl's face to the other side}}
\hadithdefcmd{nasai}{5393}{أَخْبَرَنَا مُجَاهِدُ بْنُ مُوسَى، عَنْ هُشَيْمٍ، عَنْ يَحْيَى بْنِ أَبِي إِسْحَاقَ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَجُلاً، سَأَلَ النَّبِيَّ صلى الله عليه وسلم إِنَّ أَبِي أَدْرَكَهُ الْحَجُّ وَهُوَ شَيْخٌ كَبِيرٌ لاَ يَثْبُتُ عَلَى رَاحِلَتِهِ فَإِنْ شَدَدْتُهُ خَشِيتُ أَنْ يَمُوتَ أَفَأَحُجُّ عَنْهُ قَالَ ‏"‏ أَفَرَأَيْتَ لَوْ كَانَ عَلَيْهِ دَيْنٌ فَقَضَيْتَهُ أَكَانَ مُجْزِئًا ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ فَحُجَّ عَنْ أَبِيكَ ‏"‏‏.‏\hadithno{5393}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Abbas that:A man asked the Messenger of Allah [SAW]: "The (command to perform) Hajj has come while my father is an old man and cannot sit firmly in the saddle, and if I tie him, I fear that he may die. Can I perform Hajj on his behalf?" He said: "Do you think that if he owed a debt you would pay it off for him?" He said: "Yes." He said: "Then perform Hajj on behalf of your father}}
\hadithdefcmd{nasai}{5394}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ مُحَمَّدٍ، عَنْ يَحْيَى بْنِ أَبِي إِسْحَاقَ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنِ الْفَضْلِ بْنِ الْعَبَّاسِ، أَنَّهُ كَانَ رَدِيفَ النَّبِيِّ صلى الله عليه وسلم فَجَاءَهُ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أُمِّي عَجُوزٌ كَبِيرَةٌ إِنْ حَمَلْتُهَا لَمْ تَسْتَمْسِكْ وَإِنْ رَبَطْتُهَا خَشِيتُ أَنْ أَقْتُلَهَا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرَأَيْتَ لَوْ كَانَ عَلَى أُمِّكَ دَيْنٌ أَكُنْتَ قَاضِيَهُ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ فَحُجَّ عَنْ أُمِّكَ ‏"‏‏.‏\hadithno{5394}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Al-Fadl bin 'Abbas, that:He was riding behind the Messenger of Allah [SAW], when a man came and said: "O Messenger of Allah, my mother is an old woman; if I put her on a mount she cannot sit firmly, and if I tie her, I fear that I may kill her." He said: "Do you think that if your mother owed a debt you would pay it off for her?" He said: "Yes." He said: "Then perform Hajj on behalf of your mother}}
\hadithdefcmd{nasai}{5395}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا الْوَلِيدُ بْنُ نَافِعٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ يَحْيَى بْنِ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ سُلَيْمَانَ بْنَ يَسَارٍ، يُحَدِّثُهُ عَنِ الْفَضْلِ بْنِ الْعَبَّاسِ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا نَبِيَّ اللَّهِ إِنَّ أَبِي شَيْخٌ كَبِيرٌ لاَ يَسْتَطِيعُ الْحَجَّ وَإِنْ حَمَلْتُهُ لَمْ يَسْتَمْسِكْ أَفَأَحُجَّ عَنْهُ قَالَ ‏ "‏ حُجَّ عَنْ أَبِيكَ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ سُلَيْمَانُ لَمْ يَسْمَعْ مِنَ الْفَضْلِ بْنِ الْعَبَّاسِ‏.‏\hadithno{5395}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Sulaiman bin Yasar, who narrated from Al-Fadl bin 'Abbas, who said:"A man came to the Prophet [SAW] and said: 'O Prophet of Allah, my father is an old man and cannot perform Hajj. If I put him on a mount he cannot sit firm. Can I perform Hajj on his behalf?' He said: 'Perform Hajj on behalf of your father}}
\hadithdefcmd{nasai}{5396}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ زَكَرِيَّا بْنِ إِسْحَاقَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي الشَّعْثَاءِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنَّ أَبِي شَيْخٌ كَبِيرٌ أَفَأَحُجُّ عَنْهُ قَالَ ‏ "‏ نَعَمْ أَرَأَيْتَ لَوْ كَانَ عَلَيْهِ دَيْنٌ فَقَضَيْتَهُ أَكَانَ يُجْزِئُ عَنْهُ ‏"‏‏.‏\hadithno{5396}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that:A man came to the Prophet [SAW] and said: "My father is an old man, can I perform Hajj on his behalf?" He said: "Yes. Don't you think that if he owed a debt and you paid it off, that would suffice him?}}
\hadithdefcmd{nasai}{5397}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ، هُوَ ابْنُ عُمَيْرٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، قَالَ أَكْثَرُوا عَلَى عَبْدِ اللَّهِ ذَاتَ يَوْمٍ فَقَالَ عَبْدُ اللَّهِ إِنَّهُ قَدْ أَتَى عَلَيْنَا زَمَانٌ وَلَسْنَا نَقْضِي وَلَسْنَا هُنَالِكَ ثُمَّ إِنَّ اللَّهَ عَزَّ وَجَلَّ قَدَّرَ عَلَيْنَا أَنْ بَلَغْنَا مَا تَرَوْنَ فَمَنْ عَرَضَ لَهُ مِنْكُمْ قَضَاءٌ بَعْدَ الْيَوْمِ فَلْيَقْضِ بِمَا فِي كِتَابِ اللَّهِ فَإِنْ جَاءَ أَمْرٌ لَيْسَ فِي كِتَابِ اللَّهِ فَلْيَقْضِ بِمَا قَضَى بِهِ نَبِيُّهُ صلى الله عليه وسلم فَإِنْ جَاءَ أَمْرٌ لَيْسَ فِي كِتَابِ اللَّهِ وَلاَ قَضَى بِهِ نَبِيُّهُ صلى الله عليه وسلم فَلْيَقْضِ بِمَا قَضَى بِهِ الصَّالِحُونَ فَإِنْ جَاءَ أَمْرٌ لَيْسَ فِي كِتَابِ اللَّهِ وَلاَ قَضَى بِهِ نَبِيُّهُ صلى الله عليه وسلم وَلاَ قَضَى بِهِ الصَّالِحُونَ فَلْيَجْتَهِدْ رَأْيَهُ وَلاَ يَقُولُ إِنِّي أَخَافُ وَإِنِّي أَخَافُ فَإِنَّ الْحَلاَلَ بَيِّنٌ وَالْحَرَامَ بَيِّنٌ وَبَيْنَ ذَلِكَ أُمُورٌ مُشْتَبِهَاتٌ فَدَعْ مَا يَرِيبُكَ إِلَى مَا لاَ يَرِيبُكَ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا الْحَدِيثُ جَيِّدٌ جَيِّدٌ‏.‏\hadithno{5397}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdur-Rahman bin Yazid said:"The people asked 'Abdullah too many questions one day, and 'Abdullah said: 'There was a time when we did not pass so many judgments, but now that time is over. Now Allah, the Mighty and Sublime, has decreed that we reach a time when, as you see, (we are asked to pass many judgments). Whoever among you is asked to pass a judgment after this day, let him pass judgment according to what is in the Book of Allah. If he is faced with a matter that is not mentioned in the Book of Allah, let him pass judgment according to the way His Prophet [SAW] passed judgment. If he is faced with a matter that is not mentioned in the Book of Allah and concerning which His Prophet did not pass judgment, then let him pass judgment according to the way the righteous passed judgment. If he is faced with a matter that is not mentioned in the Book of Allah, and concerning which His Prophet and the righteous did not pass judgment, then let him strive to work it out, and let him not say 'I am afraid, I am afraid.' For that which is lawful is clear and that which is unlawful is clear, and between them are matters which are not as clear. Leave that which makes you doubt for that which does not make you doubt}}
\hadithdefcmd{nasai}{5398}{أَخْبَرَنِي مُحَمَّدُ بْنُ عَلِيِّ بْنِ مَيْمُونٍ، قَالَ حَدَّثَنَا الْفِرْيَابِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ حُرَيْثِ بْنِ ظُهَيْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ أَتَى عَلَيْنَا حِينٌ وَلَسْنَا نَقْضِي وَلَسْنَا هُنَالِكَ وَإِنَّ اللَّهَ عَزَّ وَجَلَّ قَدَّرَ أَنْ بَلَغْنَا مَا تَرَوْنَ فَمَنْ عَرَضَ لَهُ قَضَاءٌ بَعْدَ الْيَوْمِ فَلْيَقْضِ فِيهِ بِمَا فِي كِتَابِ اللَّهِ فَإِنْ جَاءَ أَمْرٌ لَيْسَ فِي كِتَابِ اللَّهِ فَلْيَقْضِ بِمَا قَضَى بِهِ نَبِيُّهُ فَإِنْ جَاءَ أَمْرٌ لَيْسَ فِي كِتَابِ اللَّهِ وَلَمْ يَقْضِ بِهِ نَبِيُّهُ صلى الله عليه وسلم فَلْيَقْضِ بِمَا قَضَى بِهِ الصَّالِحُونَ وَلاَ يَقُولُ أَحَدُكُمْ إِنِّي أَخَافُ وَإِنِّي أَخَافُ فَإِنَّ الْحَلاَلَ بَيِّنٌ وَالْحَرَامَ بَيِّنٌ وَبَيْنَ ذَلِكَ أُمُورٌ مُشْتَبِهَةٌ فَدَعْ مَا يَرِيبُكَ إِلَى مَا لاَ يَرِيبُكَ‏.‏\hadithno{5398}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin Mas'ud said:"There was a time when we did not pass so many judgments, but now that time is over. Now Allah, the Mighty and Sublime, has decreed that we reach a time when, as you see, (we are asked to pass many judgments). Whoever among you is asked to pass a judgment after this day, let him pass judgment according to what is in the Book of Allah. If he is faced with a matter that is not mentioned in the Book of Allah, let him pass judgment according to the way His Prophet [SAW] passed judgment. If he is faced with a matter that is not mentioned in the Book of Allah, and concerning which His Prophet did not pass judgment, then let him pass judgment according to the way the righteous passed judgment. And let him not say 'I am afraid, I am afraid.' For that which is lawful is clear and that which is unlawful is clear, and between them are matters which are not as clear. Leave that which makes you doubt for that which does not make you doubt}}
\hadithdefcmd{nasai}{5399}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا أَبُو عَامِرٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الشَّيْبَانِيِّ، عَنِ الشَّعْبِيِّ، عَنْ شُرَيْحٍ، أَنَّهُ كَتَبَ إِلَى عُمَرَ يَسْأَلُهُ فَكَتَبَ إِلَيْهِ أَنِ اقْضِ بِمَا فِي كِتَابِ اللَّهِ فَإِنْ لَمْ يَكُنْ فِي كِتَابِ اللَّهِ فَبِسُنَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِنْ لَمْ يَكُنْ فِي كِتَابِ اللَّهِ وَلاَ فِي سُنَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَاقْضِ بِمَا قَضَى بِهِ الصَّالِحُونَ فَإِنْ لَمْ يَكُنْ فِي كِتَابِ اللَّهِ وَلاَ فِي سُنَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَمْ يَقْضِ بِهِ الصَّالِحُونَ فَإِنْ شِئْتَ فَتَقَدَّمْ وَإِنْ شِئْتَ فَتَأَخَّرْ وَلاَ أَرَى التَّأَخُّرَ إِلاَّ خَيْرًا لَكَ وَالسَّلاَمُ عَلَيْكُمْ‏.‏\hadithno{5399}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Shuraih that:He wrote to 'Umar, to ask him (a question), and 'Umar wrote back to him telling him: "Judge according to what is in the Book of Allah. If it is not (mentioned) in the Book of Allah, then (judge) according to the Sunnah of the Messenger of Allah [SAW]. If it is not (mentioned) in the Book of Allah or the Sunnah of the Messenger of Allah [SAW], then pass judgment according to the way the righteous passed judgment. If it is not (mentioned) in the Book of Allah, or the Sunnah of the Messenger of Allah [SAW], and the righteous did not pass judgment concerning it, then if you wish, go ahead (and try to work it out by yourself) or if you wish, leave it. And I think that leaving it is better for you. And peace be upon you}}
\hadithdefcmd{nasai}{5400}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ أَنْبَأَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ سُفْيَانَ بْنِ سَعِيدٍ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَتْ مُلُوكٌ بَعْدَ عِيسَى ابْنِ مَرْيَمَ عَلَيْهِ الصَّلاَةُ وَالسَّلاَمُ بَدَّلُوا التَّوْرَاةَ وَالإِنْجِيلَ وَكَانَ فِيهِمْ مُؤْمِنُونَ يَقْرَءُونَ التَّوْرَاةَ قِيلَ لِمُلُوكِهِمْ مَا نَجِدُ شَتْمًا أَشَدَّ مِنْ شَتْمٍ يَشْتِمُونَّا هَؤُلاَءِ إِنَّهُمْ يَقْرَءُونَ ‏\{‏وَمَنْ لَمْ يَحْكُمْ بِمَا أَنْزَلَ اللَّهُ فَأُولَئِكَ هُمُ الْكَافِرُونَ‏\}‏ وَهَؤُلاَءِ الآيَاتِ مَعَ مَا يَعِيبُونَّا بِهِ فِي أَعْمَالِنَا فِي قِرَاءَتِهِمْ فَادْعُهُمْ فَلْيَقْرَءُوا كَمَا نَقْرَأُ وَلْيُؤْمِنُوا كَمَا آمَنَّا‏.‏ فَدَعَاهُمْ فَجَمَعَهُمْ وَعَرَضَ عَلَيْهِمُ الْقَتْلَ أَوْ يَتْرُكُوا قِرَاءَةَ التَّوْرَاةِ وَالإِنْجِيلِ إِلاَّ مَا بَدَّلُوا مِنْهَا فَقَالُوا مَا تُرِيدُونَ إِلَى ذَلِكَ دَعُونَا‏.‏ فَقَالَتْ طَائِفَةٌ مِنْهُمُ ابْنُوا لَنَا أُسْطُوَانَةً ثُمَّ ارْفَعُونَا إِلَيْهَا ثُمَّ اعْطُونَا شَيْئًا نَرْفَعُ بِهِ طَعَامَنَا وَشَرَابَنَا فَلاَ نَرِدُ عَلَيْكُمْ‏.‏ وَقَالَتْ طَائِفَةٌ مِنْهُمْ دَعُونَا نَسِيحُ فِي الأَرْضِ وَنَهِيمُ وَنَشْرَبُ كَمَا يَشْرَبُ الْوَحْشُ فَإِنْ قَدَرْتُمْ عَلَيْنَا فِي أَرْضِكُمْ فَاقْتُلُونَا‏.‏ وَقَالَتْ طَائِفَةٌ مِنْهُمُ ابْنُوا لَنَا دُورًا فِي الْفَيَافِي وَنَحْتَفِرُ الآبَارَ وَنَحْتَرِثُ الْبُقُولَ فَلاَ نَرِدُ عَلَيْكُمْ وَلاَ نَمُرُّ بِكُمْ وَلَيْسَ أَحَدٌ مِنَ الْقَبَائِلِ إِلاَّ وَلَهُ حَمِيمٌ فِيهِمْ‏.‏ قَالَ فَفَعَلُوا ذَلِكَ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏وَرَهْبَانِيَّةً ابْتَدَعُوهَا مَا كَتَبْنَاهَا عَلَيْهِمْ إِلاَّ ابْتِغَاءَ رِضْوَانِ اللَّهِ فَمَا رَعَوْهَا حَقَّ رِعَايَتِهَا‏\}‏ وَالآخَرُونَ قَالُوا نَتَعَبَّدُ كَمَا تَعَبَّدَ فُلاَنٌ وَنَسِيحُ كَمَا سَاحَ فُلاَنٌ وَنَتَّخِذُ دُورًا كَمَا اتَّخَذَ فُلاَنٌ‏.‏ وَهُمْ عَلَى شِرْكِهِمْ لاَ عِلْمَ لَهُمْ بِإِيمَانِ الَّذِينَ اقْتَدَوْا بِهِ فَلَمَّا بَعَثَ اللَّهُ النَّبِيَّ صلى الله عليه وسلم وَلَمْ يَبْقَ مِنْهُمْ إِلاَّ قَلِيلٌ انْحَطَّ رَجُلٌ مِنْ صَوْمَعَتِهِ وَجَاءَ سَائِحٌ مِنْ سِيَاحَتِهِ وَصَاحِبُ الدَّيْرِ مِنْ دَيْرِهِ فَآمَنُوا بِهِ وَصَدَّقُوهُ فَقَالَ اللَّهُ تَبَارَكَ وَتَعَالَى ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا اتَّقُوا اللَّهَ وَآمِنُوا بِرَسُولِهِ يُؤْتِكُمْ كِفْلَيْنِ مِنْ رَحْمَتِهِ‏\}‏ أَجْرَيْنِ بِإِيمَانِهِمْ بِعِيسَى وَبِالتَّوْرَاةِ وَالإِنْجِيلِ وَبِإِيمَانِهِمْ بِمُحَمَّدٍ صلى الله عليه وسلم وَتَصْدِيقِهِمْ قَالَ ‏\{‏يَجْعَلْ لَكُمْ نُورًا تَمْشُونَ بِهِ‏\}‏ الْقُرْآنَ وَاتِّبَاعَهُمُ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏\{‏لِئَلاَّ يَعْلَمَ أَهْلُ الْكِتَابِ‏\}‏ يَتَشَبَّهُونَ بِكُمْ ‏\{‏أَنْ لاَ يَقْدِرُونَ عَلَى شَىْءٍ مِنْ فَضْلِ اللَّهِ‏\}‏ الآيَةَ‏.‏\hadithno{5400}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"There were kings after 'Isa bin Mariam who altered the Tawrah and the Injil, but there were among them believers who read the Tawrah. It was said to their kings: 'We have never heard of any slander worse than that of those (believers) who slander us and recite: "And whosoever does not judge by what Allah has revealed, such are the disbelievers." In these Verses, they are criticizing us for our deeds when they recite them.' So he called them together and gave them the choice between being put to death, or giving up reading the Tawrah and Injil, except for what had been altered. They said: 'Why do you want us to change? Leave us alone.' Some of them said: 'Build us a tower and let us go up there, and give us something to lift up our food and drink so we do not have to mix with you.' Others said: 'Let us go and wander throughout the land, and we will drink as the wild animals drink, and if you capture us in your land, you may kill us.' Others said: 'Build houses for us in the wilderness, and we will dig wells and grow vegetables, and we will not mix with you or pass by you, for there is no one of the tribes among whom we do not have close relatives.' So they did that, and Allah revealed the words: 'But the monasticism which they invented for themselves, We did not prescribe for them, but (they sought it) only to please Allah therewith, but that they did not observe it with the right observance.' Then others said: 'We will worship as so-and-so worshipped, and we will wander as so-and-so wandered, and we will adopt houses (in the wilderness) as so-and-so did.' But they were still following their Shirk with no knowledge of the faith of those whom they claimed to be following. When Allah sent the Prophet [SAW], and they were only a few of them left, a man came down from his cell, and a wanderer came from his travels, and a monk came from his monastery, and they believed in him. And Allah said: 'O you who believe! Fear Allah, and believe in His Messenger (Muhammad), He will give you a double portion of His mercy - meaning, two rewards, because of their having believed in 'Isa and in the Tawrah and Injil, and for having believing in Muhammad [SAW]; and He will give you a light by which you shall walk (straight), - meaning, the Qur'an, and their following the Prophet [SAW]; and He said: 'So that the people of the Scripture (Jews and Christians) may know that they have no power whatsoever over the Grace of Allah}}
\hadithdefcmd{nasai}{5401}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، قَالَ حَدَّثَنِي أَبِي، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّكُمْ تَخْتَصِمُونَ إِلَىَّ وَإِنَّمَا أَنَا بَشَرٌ وَلَعَلَّ بَعْضَكُمْ أَلْحَنُ بِحُجَّتِهِ مِنْ بَعْضٍ فَمَنْ قَضَيْتُ لَهُ مِنْ حَقِّ أَخِيهِ شَيْئًا فَلاَ يَأْخُذْهُ فَإِنَّمَا أَقْطَعُهُ بِهِ قِطْعَةً مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{5401}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Umm Salamah that:The Messenger of Allah [SAW] said: "You refer your disputes to me, but I am only human, and some of you may be more eloquent in arguing their case than others. If I pass judgment in favor of one of you, against his brother's rights, let him not take it, for it is a piece of fire that I am giving him}}
\hadithdefcmd{nasai}{5402}{أَخْبَرَنَا عِمْرَانُ بْنُ بَكَّارِ بْنِ رَاشِدٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ عَيَّاشٍ، قَالَ حَدَّثَنَا شُعَيْبٌ، قَالَ حَدَّثَنِي أَبُو الزِّنَادِ، مِمَّا حَدَّثَهُ عَبْدُ الرَّحْمَنِ الأَعْرَجُ، مِمَّا ذَكَرَ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يُحَدِّثُ بِهِ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ وَقَالَ ‏ "‏ بَيْنَمَا امْرَأَتَانِ مَعَهُمَا ابْنَاهُمَا جَاءَ الذِّئْبُ فَذَهَبَ بِابْنِ إِحْدَاهُمَا فَقَالَتْ هَذِهِ لِصَاحِبَتِهَا إِنَّمَا ذَهَبَ بِابْنِكِ ‏.‏ وَقَالَتِ الأُخْرَى إِنَّمَا ذَهَبَ بِابْنِكِ ‏.‏ فَتَحَاكَمَتَا إِلَى دَاوُدَ عَلَيْهِ السَّلاَمُ فَقَضَى بِهِ لِلْكُبْرَى فَخَرَجَتَا إِلَى سُلَيْمَانَ بْنِ دَاوُدَ فَأَخْبَرَتَاهُ فَقَالَ ائْتُونِي بِالسِّكِّينِ أَشُقُّهُ بَيْنَهُمَا ‏.‏ فَقَالَتِ الصُّغْرَى لاَ تَفْعَلْ يَرْحَمُكَ اللَّهُ هُوَ ابْنُهَا ‏.‏ فَقَضَى بِهِ لِلصُّغْرَى ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ وَاللَّهِ مَا سَمِعْتُ بِالسِّكِّينِ قَطُّ إِلاَّ يَوْمَئِذٍ مَا كُنَّا نَقُولُ إِلاَّ الْمُدْيَةَ ‏.‏\hadithno{5402}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah [SAW] said: "There were two woman who had two children, and the wolf came and took away the son of one of them. She said to her companion: 'It took away your son.' The other one said: 'No, it took away your son.' They referred the matter to Dawud, peace be upon him, for judgment (about the remaining child) and he ruled in favor of the older one. Then they went out to Sulaiman bin Dawud and told him (about that). He said: 'Give me a knife and I will cut him in half (to be shared) between you.' The younger one said: 'Do not do that, may Allah have mercy on you; he is her son.' So he ruled that (the child) belonged to the younger woman." Abu Hurairah said: "By Allah! I never heard 'Sikkin' used until that day. We would only say: 'Mudyah}}
\hadithdefcmd{nasai}{5403}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ اللَّيْثِ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ خَرَجَتِ امْرَأَتَانِ مَعَهُمَا صَبِيَّانِ لَهُمَا فَعَدَا الذِّئْبُ عَلَى إِحْدَاهُمَا فَأَخَذَ وَلَدَهَا فَأَصْبَحَتَا تَخْتَصِمَانِ فِي الصَّبِيِّ الْبَاقِي إِلَى دَاوُدَ عَلَيْهِ السَّلاَمُ فَقَضَى بِهِ لِلْكُبْرَى مِنْهُمَا فَمَرَّتَا عَلَى سُلَيْمَانَ فَقَالَ كَيْفَ أَمْرُكُمَا فَقَصَّتَا عَلَيْهِ فَقَالَ ائْتُونِي بِالسِّكِّينِ أَشُقُّ الْغُلاَمَ بَيْنَهُمَا ‏.‏ فَقَالَتِ الصُّغْرَى أَتَشُقُّهُ قَالَ نَعَمْ ‏.‏ فَقَالَتْ لاَ تَفْعَلْ حَظِّي مِنْهُ لَهَا ‏.‏ قَالَ ‏.‏ هُوَ ابْنُكِ ‏.‏ فَقَضَى بِهِ لَهَا ‏"‏ ‏.‏\hadithno{5403}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah [SAW] said: "Two women went out with two children of theirs, and the wolf attacked one of them and took her child. The next day they referred their dispute over the remaining child to Dawud, peace be upon him, and he ruled that (the child) belonged to the older woman. Then they passed by Sulaiman and he said: 'What is your story?' So they told him. He said: 'Bring me a knife and I will cut him in half (to be shared) between you.' The younger one said: 'Will you cut him in half?' He said: 'Yes.' She said: 'Do not do that; I will give my share of him to her.' He said: 'He is your child' and he ruled that he belonged to her}}
\hadithdefcmd{nasai}{5404}{أَخْبَرَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا مِسْكِينُ بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ أَبِي حَمْزَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خَرَجَتِ امْرَأَتَانِ مَعَهُمَا وَلَدَاهُمَا فَأَخَذَ الذِّئْبُ أَحَدَهُمَا فَاخْتَصَمَتَا فِي الْوَلَدِ إِلَى دَاوُدَ النَّبِيِّ صلى الله عليه وسلم فَقَضَى بِهِ لِلْكُبْرَى مِنْهُمَا فَمَرَّتَا عَلَى سُلَيْمَانَ عَلَيْهِ السَّلاَمُ فَقَالَ كَيْفَ قَضَى بَيْنَكُمَا قَالَتْ قَضَى بِهِ لِلْكُبْرَى ‏.‏ قَالَ سُلَيْمَانُ أَقْطَعُهُ بِنِصْفَيْنِ لِهَذِهِ نِصْفٌ وَلِهَذِهِ نِصْفٌ ‏.‏ قَالَتِ الْكُبْرَى نَعَمِ اقْطَعُوهُ ‏.‏ فَقَالَتِ الصُّغْرَى لاَ تَقْطَعْهُ هُوَ وَلَدُهَا ‏.‏ فَقَضَى بِهِ لِلَّتِي أَبَتْ أَنْ يَقْطَعَهُ ‏"‏ ‏.‏\hadithno{5404}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that :The Prophet [SAW] said: "Two women went out with their two children, and the wolf took one of the children from them. They referred their dispute to Prophet Dawud, peace be upon him, and he ruled that (the remaining child) belonged to the older woman. Then they passed by Sulaiman, peace be upon him, and he said: 'How did he judge between you?' She said: 'He ruled that (the child) belongs to the older woman.' Sulaiman said: 'Cut him in half, and give half to one and half to the other.' The older woman said: 'Yes, cut him in half.' The younger woman said: 'Do not cut him, he is her child.' So he ruled that the child belonged to the woman who refused to let him be cut}}
\hadithdefcmd{nasai}{5405}{أَخْبَرَنَا زَكَرِيَّا بْنُ يَحْيَى، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، ح وَأَنْبَأَنَا أَحْمَدُ بْنُ عَلِيِّ بْنِ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، قَالَ حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، وَعَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ بَعَثَ النَّبِيُّ صلى الله عليه وسلم خَالِدَ بْنَ الْوَلِيدِ إِلَى بَنِي جَذِيمَةَ فَدَعَاهُمْ إِلَى الإِسْلاَمِ فَلَمْ يُحْسِنُوا أَنْ يَقُولُوا أَسْلَمْنَا فَجَعَلُوا يَقُولُونَ صَبَأْنَا وَجَعَلَ خَالِدٌ قَتْلاً وَأَسْرًا - قَالَ - فَدَفَعَ إِلَى كُلِّ رَجُلٍ أَسِيرَهُ حَتَّى إِذَا أَصْبَحَ يَوْمُنَا أَمَرَ خَالِدُ بْنُ الْوَلِيدِ أَنْ يَقْتُلَ كُلُّ رَجُلٍ مِنَّا أَسِيرَهُ ‏.‏ قَالَ ابْنُ عُمَرَ فَقُلْتُ وَاللَّهِ لاَ أَقْتُلُ أَسِيرِي وَلاَ يَقْتُلُ أَحَدٌ - وَقَالَ بِشْرٌ - مِنْ أَصْحَابِي أَسِيرَهُ - قَالَ - فَقَدِمْنَا عَلَى النَّبِيِّ صلى الله عليه وسلم فَذُكِرَ لَهُ صُنْعُ خَالِدٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم وَرَفَعَ يَدَيْهِ ‏"‏ اللَّهُمَّ إِنِّي أَبْرَأُ إِلَيْكَ مِمَّا صَنَعَ خَالِدٌ ‏"‏ ‏.‏ قَالَ زَكَرِيَّا فِي حَدِيثِهِ فَذُكِرَ وَفِي حَدِيثِ بِشْرٍ فَقَالَ ‏"‏ اللَّهُمَّ إِنِّي أَبْرَأُ إِلَيْكَ مِمَّا صَنَعَ خَالِدٌ ‏"‏ ‏.‏ مَرَّتَيْنِ ‏.‏\hadithno{5405}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Salim that his father said:"The Prophet [SAW] sent Khalid bin Al-Walid to Banu Jadhimah. He called them to Islam, but they could not say Aslamna (we submitted, i.e., became Muslim) so they started to say Saba'na (we changed our religion). Khalid started killing and taking prisoners, and he gave a prisoner to each man. The next day Khalid bin Al-Walid issued orders that each man among us kill his prisoner." Ibn 'Umar said: "I said: 'By Allah, I will not kill my prisoner, and no one (among my companions) will kill his prisoner.' We came to the Prophet [SAW], and he was told of what Khalid had done. The Prophet [SAW] said: 'I disavow what Khalid has done,' twice}}
\hadithdefcmd{nasai}{5406}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، قَالَ كَتَبَ أَبِي وَكَتَبْتُ لَهُ إِلَى عُبَيْدِ اللَّهِ بْنِ أَبِي بَكْرَةَ وَهُوَ قَاضِي سِجِسْتَانَ أَنْ لاَ، تَحْكُمَ بَيْنَ اثْنَيْنِ وَأَنْتَ غَضْبَانُ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحْكُمْ أَحَدٌ بَيْنَ اثْنَيْنِ وَهُوَ غَضْبَانُ ‏"‏ ‏.‏\hadithno{5406}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdur-Rahman bin Abi Bakrah said:"My father wrote to 'Ubaidullah bin Abi Bakrah - who was the judge of Sijistan - saying: 'Do not pass judgment between two people when you are angry, for I heard the Messenger of Allah [SAW] say: No one should pass judgment between two people when he is angry}}
\hadithdefcmd{nasai}{5407}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، وَالْحَارِثُ بْنُ مِسْكِينٍ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، وَاللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ، حَدَّثَهُ أَنَّ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ حَدَّثَهُ عَنِ الزُّبَيْرِ بْنِ الْعَوَّامِ، أَنَّهُ خَاصَمَ رَجُلاً مِنَ الأَنْصَارِ قَدْ شَهِدَ بَدْرًا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي شِرَاجِ الْحَرَّةِ كَانَا يَسْقِيَانِ بِهِ كِلاَهُمَا النَّخْلَ فَقَالَ الأَنْصَارِيُّ سَرِّحِ الْمَاءَ يَمُرَّ عَلَيْهِ ‏.‏ فَأَبَى عَلَيْهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اسْقِ يَا زُبَيْرُ ثُمَّ أَرْسِلِ الْمَاءَ إِلَى جَارِكَ ‏"‏ ‏.‏ فَغَضِبَ الأَنْصَارِيُّ وَقَالَ يَا رَسُولَ اللَّهِ أَنْ كَانَ ابْنَ عَمَّتِكَ فَتَلَوَّنَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ يَا زُبَيْرُ اسْقِ ثُمَّ احْبِسِ الْمَاءَ حَتَّى يَرْجِعَ إِلَى الْجَدْرِ ‏"‏ ‏.‏ فَاسْتَوْفَى رَسُولُ اللَّهِ صلى الله عليه وسلم لِلزُّبَيْرِ حَقَّهُ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَبْلَ ذَلِكَ أَشَارَ عَلَى الزُّبَيْرِ بِرَأْىٍ فِيهِ السَّعَةُ لَهُ وَلِلأَنْصَارِيِّ فَلَمَّا أَحْفَظَ رَسُولَ اللَّهِ صلى الله عليه وسلم الأَنْصَارِيُّ اسْتَوْفَى لِلزُّبَيْرِ حَقَّهُ فِي صَرِيحِ الْحُكْمِ ‏.‏ قَالَ الزُّبَيْرُ لاَ أَحْسَبُ هَذِهِ الآيَةَ أُنْزِلَتْ إِلاَّ فِي ذَلِكَ ‏\{‏ فَلاَ وَرَبِّكَ لاَ يُؤْمِنُونَ حَتَّى يُحَكِّمُوكَ فِيمَا شَجَرَ بَيْنَهُمْ ‏\}‏ وَأَحَدُهُمَا يَزِيدُ عَلَى صَاحِبِهِ فِي الْقِصَّةِ ‏.‏\hadithno{5407}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Az-Zubair bin Al-'Awwam that:He disputed with a man among Ansar who had been present at Badr with the Messenger of Allah [SAW], concerning a stream in Al-Harrah from which they both used to water their date palm trees. The Ansari said: "Let the water flow." But he (Az-Zubair) refused. The Messenger of Allah [SAW] said: "Irrigate (your land), O Zubair! Then let the water flow to your neighbor." The Ansari became angry and said, "O Messenger of Allah, is it because he is your cousin?" The face of the Messenger of Allah [SAW] changed color (because of anger) and he said: "O Zubair! Irrigate (your land) then block the water, until it flows back to the walls." So the Messenger of Allah [SAW] allowed Az-Zubair to take his rights in full, although before that he had suggested to Az-Zubair a middle way that benefited both him and the Ansari. But when the Ansari made the Messenger of Allah [SAW] angry, he gave Az-Zubair his rights in full, as stated clearly in his ruling. Az-Zubair said: "I think that this Verse was revealed concerning this matter: 'But no, by your Lord, they can have no faith, until they make you (O Muhammad) judge in all disputes between them}}
\hadithdefcmd{nasai}{5408}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، قَالَ أَنْبَأَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ كَعْبٍ، عَنْ أَبِيهِ، أَنَّهُ تَقَاضَى ابْنَ أَبِي حَدْرَدٍ دَيْنًا كَانَ عَلَيْهِ فَارْتَفَعَتْ أَصْوَاتُهُمَا حَتَّى سَمِعَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ فِي بَيْتِهِ فَخَرَجَ إِلَيْهِمَا فَكَشَفَ سِتْرَ حُجْرَتِهِ فَنَادَى ‏"‏ يَا كَعْبُ ‏"‏ ‏.‏ قَالَ لَبَّيْكَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ ضَعْ مِنْ دَيْنِكَ هَذَا ‏"‏ ‏.‏ وَأَوْمَأَ إِلَى الشَّطْرِ قَالَ قَدْ فَعَلْتُ ‏.‏ قَالَ ‏"‏ قُمْ فَاقْضِهِ ‏"‏ ‏.‏\hadithno{5408}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin Ka'b, from his father, that :He asked Ibn Abi Hadrad to pay off a debt that he owed him. Their voices grew so loud that the Messenger of Allah [SAW] heard them when he was inside his house. He came out to them, drew back the curtain of his room and called out: "O Ka'b!" He said: "Here I am, O Messenger of Allah." He said: "Drop his debt to half." He said: "I will do that." He said (to the debtor): "Go and pay it off}}
\hadithdefcmd{nasai}{5409}{أَخْبَرَنَا الْحُسَيْنُ بْنُ مَنْصُورِ بْنِ جَعْفَرٍ، قَالَ حَدَّثَنَا مُبَشِّرُ بْنُ عَبْدِ اللَّهِ بْنِ رَزِينٍ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ حُسَيْنٍ، عَنْ أَبِي بِشْرٍ، جَعْفَرِ بْنِ إِيَاسٍ عَنْ عَبَّادِ بْنِ شَرَاحِيلَ، قَالَ قَدِمْتُ مَعَ عُمُومَتِي الْمَدِينَةَ فَدَخَلْتُ حَائِطًا مِنْ حِيطَانِهَا فَفَرَكْتُ مِنْ سُنْبُلِهِ فَجَاءَ صَاحِبُ الْحَائِطِ فَأَخَذَ كِسَائِي وَضَرَبَنِي فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَسْتَعْدِي عَلَيْهِ فَأَرْسَلَ إِلَى الرَّجُلِ فَجَاءُوا بِهِ فَقَالَ ‏"‏ مَا حَمَلَكَ عَلَى هَذَا ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّهُ دَخَلَ حَائِطِي فَأَخَذَ مِنْ سُنْبُلِهِ فَفَرَكَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا عَلَّمْتَهُ إِذْ كَانَ جَاهِلاً وَلاَ أَطْعَمْتَهُ إِذْ كَانَ جَائِعًا ارْدُدْ عَلَيْهِ كِسَاءَهُ ‏"‏ ‏.‏ وَأَمَرَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم بِوَسْقٍ أَوْ نِصْفِ وَسْقٍ ‏.‏\hadithno{5409}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abbad bin Shurahbil said:"I came to Al-Madinah with my paternal uncles and entered one of its gardens, where I rubbed an ear of grain (to take some grains). The owner of the garden came, took my cloak and hit me. I came to the Messenger of Allah [SAW] and sought his help against him. He sent for the man and they brought him. He said: 'What made you do that?' He said: 'O Messenger of Allah, he entered my garden and took one of the ears of grain and rubbed it.' The Messenger of Allah [SAW] said: 'You did not teach him if he was ignorant, nor feed him if he was hungry. Give him back his cloak.' And the Messenger of Allah [SAW] ordered me with a Wasq or half a Wasq}}
\hadithdefcmd{nasai}{5410}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّهُمَا أَخْبَرَاهُ أَنَّ رَجُلَيْنِ اخْتَصَمَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَحَدُهُمَا اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ ‏.‏ وَقَالَ الآخَرُ وَهُوَ أَفْقَهُهُمَا ‏.‏ أَجَلْ يَا رَسُولَ اللَّهِ وَائْذَنْ لِي فِي أَنْ أَتَكَلَّمَ ‏.‏ قَالَ إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا فَزَنَى بِامْرَأَتِهِ فَأَخْبَرُونِي أَنَّ عَلَى ابْنِي الرَّجْمَ فَافْتَدَيْتُ بِمِائَةِ شَاةٍ وَبِجَارِيَةٍ لِي ثُمَّ إِنِّي سَأَلْتُ أَهْلَ الْعِلْمِ فَأَخْبَرُونِي أَنَّمَا عَلَى ابْنِي جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ وَإِنَّمَا الرَّجْمُ عَلَى امْرَأَتِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ أَمَّا غَنَمُكَ وَجَارِيَتُكَ فَرَدٌّ إِلَيْكَ ‏"‏ ‏.‏ وَجَلَدَ ابْنَهُ مِائَةً وَغَرَّبَهُ عَامًا وَأَمَرَ أُنَيْسًا أَنْ يَأْتِيَ امْرَأَةَ الآخَرِ ‏"‏ فَإِنِ اعْتَرَفَتْ فَارْجُمْهَا ‏"‏ ‏.‏ فَاعْتَرَفَتْ فَرَجَمَهَا ‏.‏\hadithno{5410}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah and Zaid bin Khalid Al-Juhani that:Two men referred a dispute to the Messenger of Allah [SAW]. One of them said: "O Messenger of Allah, pass judgment between us according to the Book of Allah." The other, who was wiser, said: "Yes, O Messenger of Allah, and allow me to speak." He said: "My son was a laborer serving this man, and he committed Zina with his wife. They told me that my son was to be stoned to death, but I ransomed him with one hundred sheep and a slave girl of mine. Then I asked the people of knowledge, who told me that my son was to be given one hundred lashes and exiled for a year, and that his (the man's) wife was to be stoned to death." The Messenger of Allah [SAW] said: "By the One in Whose hand is my soul, I will pass judgment between you according to the Book of Allah. As for your sheep and your slave girl, take them back." Then he gave his son one hundred lashes, and exiled him for one year, and he ordered Unais to go to the wife of the other man and if she confessed, to stone her to death. She did confess, so he stoned her to death}}
\hadithdefcmd{nasai}{5411}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ، وَشِبْلٍ، قَالُوا كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَامَ إِلَيْهِ رَجُلٌ فَقَالَ أَنْشُدُكَ بِاللَّهِ إِلاَّ مَا قَضَيْتَ بَيْنَنَا بِكِتَابِ اللَّهِ ‏.‏ فَقَامَ خَصْمُهُ - وَكَانَ أَفْقَهَ مِنْهُ - فَقَالَ صَدَقَ اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ ‏.‏ قَالَ ‏"‏ قُلْ ‏"‏ ‏.‏ قَالَ إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا فَزَنَى بِامْرَأَتِهِ فَافْتَدَيْتُ مِنْهُ بِمِائَةِ شَاةٍ وَخَادِمٍ - وَكَأَنَّهُ أُخْبِرَ أَنَّ عَلَى ابْنِهِ الرَّجْمَ فَافْتَدَى مِنْهُ - ثُمَّ سَأَلْتُ رِجَالاً مِنْ أَهْلِ الْعِلْمِ فَأَخْبَرُونِي أَنَّ عَلَى ابْنِي جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ عَزَّ وَجَلَّ أَمَّا الْمِائَةُ شَاةٍ وَالْخَادِمُ فَرَدٌّ عَلَيْكَ وَعَلَى ابْنِكَ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ اغْدُ يَا أُنَيْسُ عَلَى امْرَأَةِ هَذَا فَإِنِ اعْتَرَفَتْ فَارْجُمْهَا ‏"‏ ‏.‏ فَغَدَا عَلَيْهَا فَاعْتَرَفَتْ فَرَجَمَهَا ‏.‏\hadithno{5411}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah, Zaid bin Khalid and Shibl said:"We were with the Prophet [SAW] when a man stood up and said: 'I adjure you, by Allah, pass judgment between us according to the Book of Allah.' His opponent, who was wiser than him, stood up and said: 'He is right, pass judgment between us according to the Book of Allah.' He said: 'Speak.' He said: 'My son was a laborer serving this man, and he committed Zina with his wife. I ransomed him with one hundred sheep and a servant.' It is as if he was told that his son was to be stoned to death but he ransomed him from that. 'Then I asked some knowledgeable men and they told me that my son was to be given one hundred lashes and exiled for a year.' The Messenger of Allah [SAW] said to him: 'By the One in Whose hand is my soul, I will pass judgment between you according to the Book of Allah, the Mighty and Sublime. As for the one hundred sheep and the servant, take them back, and your son is to be given one hundred lashes and exiled for a year. O Unais, go tomorrow to the wife of this man and if she confesses, then stone her to death.' She did confess, so he stoned her to death}}
\hadithdefcmd{nasai}{5412}{أَخْبَرَنَا الْحَسَنُ بْنُ أَحْمَدَ الْكَرْمَانِيُّ، قَالَ حَدَّثَنَا أَبُو الرَّبِيعِ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أُتِيَ بِامْرَأَةٍ قَدْ زَنَتْ فَقَالَ ‏ "‏ مِمَّنْ ‏"‏ ‏.‏ قَالَتْ مِنَ الْمُقْعَدِ الَّذِي فِي حَائِطِ سَعْدٍ ‏.‏ فَأَرْسَلَ إِلَيْهِ فَأُتِيَ بِهِ مَحْمُولاً فَوُضِعَ بَيْنَ يَدَيْهِ فَاعْتَرَفَ فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِإِثْكَالٍ فَضَرَبَهُ وَرَحِمَهُ لِزَمَانَتِهِ وَخَفَّفَ عَنْهُ ‏.‏\hadithno{5412}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Umamah bin Sahl bin Hunaif that:A woman who had committed Zina was brought to the Prophet [SAW]. He said: "With whom?" She said: "With the paralyzed man who lives in the garden of Sa'd." He was brought and placed before (the Prophet [SAW]) and he confessed. The Messenger of Allah [SAW] called for a bunch of palm leaves and hit him. He took pity on him because of his disability and was lenient with him}}
\hadithdefcmd{nasai}{5413}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا أَبُو حَازِمٍ، قَالَ سَمِعْتُ سَهْلَ بْنَ سَعْدٍ السَّاعِدِيَّ، يَقُولُ وَقَعَ بَيْنَ حَيَّيْنِ مِنَ الأَنْصَارِ كَلاَمٌ حَتَّى تَرَامَوْا بِالْحِجَارَةِ فَذَهَبَ النَّبِيُّ صلى الله عليه وسلم لِيُصْلِحَ بَيْنَهُمْ فَحَضَرَتِ الصَّلاَةُ فَأَذَّنَ بِلاَلٌ وَانْتُظِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَاحْتُبِسَ فَأَقَامَ الصَّلاَةَ وَتَقَدَّمَ أَبُو بَكْرٍ رضى الله عنه فَجَاءَ النَّبِيُّ صلى الله عليه وسلم وَأَبُو بَكْرٍ يُصَلِّي بِالنَّاسِ فَلَمَّا رَآهُ النَّاسُ صَفَّحُوا - وَكَانَ أَبُو بَكْرٍ لاَ يَلْتَفِتُ فِي الصَّلاَةِ - فَلَمَّا سَمِعَ تَصْفِيحَهُمُ الْتَفَتَ فَإِذَا هُوَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم أَرَادَ أَنْ يَتَأَخَّرَ فَأَشَارَ إِلَيْهِ أَنِ اثْبُتْ فَرَفَعَ أَبُو بَكْرٍ رضى الله عنه يَعْنِي يَدَيْهِ ثُمَّ نَكَصَ الْقَهْقَرَى وَتَقَدَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى فَلَمَّا قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم الصَّلاَةَ قَالَ ‏"‏ مَا مَنَعَكَ أَنْ تَثْبُتَ ‏"‏ ‏.‏ قَالَ مَا كَانَ اللَّهُ لِيَرَى ابْنَ أَبِي قُحَافَةَ بَيْنَ يَدَىْ نَبِيِّهِ ‏.‏ ثُمَّ أَقْبَلَ عَلَى النَّاسِ فَقَالَ ‏"‏ مَا لَكُمْ إِذَا نَابَكُمْ شَىْءٌ فِي صَلاَتِكُمْ صَفَّحْتُمْ إِنَّ ذَلِكَ لِلنِّسَاءِ مَنْ نَابَهُ شَىْءٌ فِي صَلاَتِهِ فَلْيَقُلْ سُبْحَانَ اللَّهِ ‏"‏ ‏.‏\hadithno{5413}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Sahl bin Sa'd Al-Sa'idi said:"Words were exchanged between two clans of the Ansar, to the point that they began to throw rocks at one another. The Prophet [SAW] went to reconcile between them. The time for prayer came, so Bilal called Adhan and waited for the Messenger of Allah [SAW], but he was delayed. He said the Iqamah and Abu Bakr, may Allah be pleased with him, went forward (to lead the prayer). Then the Prophet [SAW] came while Abu Bakr was leading the people in prayer, and when the people saw him they clapped. Abu Bakr would not turn around when he was praying, but when he heard them clapping, he turned around and saw the Messenger of Allah [SAW]. He wanted to step back but (the Prophet [SAW]) gestured to him to stay where he was. Abu Bakr, may Allah be pleased with him, raised his hands, then he moved backward and the Messenger of Allah [SAW] came forward and led (the rest of) the prayer. When the Messenger of Allah [SAW] finished praying, he said: 'What prevented you from staying where you were?' He said: 'I would not like Allah to see the son of Abu Quhafah standing in front of His Prophet.' Then he (the Prophet [SAW]) turned to the people and said: 'If you noticed something while you were praying, why did you clap? That is for women. Whoever notices something while he is praying, let him say: "Subhan Allah}}
\hadithdefcmd{nasai}{5414}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ اللَّيْثِ، عَنْ أَبِيهِ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ الأَنْصَارِيِّ، عَنْ كَعْبِ بْنِ مَالِكٍ، أَنَّهُ كَانَ لَهُ عَلَى عَبْدِ اللَّهِ بْنِ أَبِي حَدْرَدٍ الأَسْلَمِيِّ - يَعْنِي دَيْنًا - فَلَقِيَهُ فَلَزِمَهُ فَتَكَلَّمَا حَتَّى ارْتَفَعَتِ الأَصْوَاتُ فَمَرَّ بِهِمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ يَا كَعْبُ ‏"‏ ‏.‏ فَأَشَارَ بِيَدِهِ كَأَنَّهُ يَقُولُ النِّصْفَ فَأَخَذَ نِصْفًا مِمَّا عَلَيْهِ وَتَرَكَ نِصْفًا ‏.‏\hadithno{5414}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ka'b bin Malik that:He owed a debt by 'Abdullah bin Abi Hadrad Al-Aslami. He met him, and asked him to pay it off. They exchanged words until their voices became loud. The Messenger of Allah [SAW] passed by them and said: "O Ka'b!" and he gestured with his hand to say half. So he took half of what was owed and let him off the other half}}
\hadithdefcmd{nasai}{5415}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عَوْفٍ، قَالَ حَدَّثَنِي حَمْزَةُ أَبُو عُمَرَ الْعَائِذِيُّ، قَالَ حَدَّثَنَا عَلْقَمَةُ بْنُ وَائِلٍ، عَنْ وَائِلٍ، قَالَ شَهِدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ جَاءَ بِالْقَاتِلِ يَقُودُهُ وَلِيُّ الْمَقْتُولِ فِي نِسْعَةٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِوَلِيِّ الْمَقْتُولِ ‏"‏ أَتَعْفُو ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَتَأْخُذُ الدِّيَةَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَتَقْتُلُهُ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ اذْهَبْ بِهِ ‏"‏ ‏.‏ فَلَمَّا ذَهَبَ فَوَلَّى مِنْ عِنْدِهِ دَعَاهُ فَقَالَ ‏"‏ أَتَعْفُو ‏"‏ ‏.‏ قَالَ لاَ قَالَ ‏"‏ فَتَأْخُذُ الدِّيَةَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَتَقْتُلُهُ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ اذْهَبْ بِهِ ‏"‏ ‏.‏ فَلَمَّا ذَهَبَ فَوَلَّى مِنْ عِنْدِهِ دَعَاهُ فَقَالَ ‏"‏ أَتَعْفُو ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَتَأْخُذُ الدِّيَةَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَتَقْتُلُهُ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ اذْهَبْ بِهِ ‏"‏ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَ ذَلِكَ ‏"‏ أَمَا إِنَّكَ إِنْ عَفَوْتَ عَنْهُ يَبُوءُ بِإِثْمِهِ وَإِثْمِ صَاحِبِكَ ‏"‏ ‏.‏ فَعَفَا عَنْهُ وَتَرَكَهُ فَأَنَا رَأَيْتُهُ يَجُرُّ نِسْعَتَهُ ‏.‏\hadithno{5415}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Wa'il said:"I saw the Messenger of Allah [SAW] when a killer was brought by the heir of the victim by a string. The Messenger of Allah [SAW] said to the heir of the victim: 'Will you forgive him?' He said: 'No.' He said: 'Will you accept the Diyah?' He said: 'No.' He said: 'Will you kill him?' He said: 'Yes.' He said: 'Take him away.' When he went and turned away from him, he called him back and said: 'Will you forgive him?' He said: 'No.' He said: 'Will you accept the Diyah?' He said: 'No.' He said: 'Will you kill him?' He said: 'Yes.' He said: 'Take him away.' When he went and turned away from him, he called him back and said: 'Will you forgive him?' He said: 'No.' He said: 'Will you accept the Diyah?' He said: 'No.' He said: 'Will you kill him?' He said: 'Yes.' He said: 'Take him away.' At that point the Messenger of Allah [SAW] said: 'But if you forgive him, he will carry his own sin and the sin of your companion.' So he forgave him, and I saw him dragging his string}}
\hadithdefcmd{nasai}{5416}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّهُ حَدَّثَهُ أَنَّ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ حَدَّثَهُ أَنَّ رَجُلاً مِنَ الأَنْصَارِ خَاصَمَ الزُّبَيْرَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فِي شِرَاجِ الْحَرَّةِ الَّتِي يَسْقُونَ بِهَا النَّخْلَ فَقَالَ الأَنْصَارِيُّ سَرِّحِ الْمَاءَ يَمُرَّ ‏.‏ فَأَبَى عَلَيْهِ فَاخْتَصَمُوا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اسْقِ يَا زُبَيْرُ ثُمَّ أَرْسِلِ الْمَاءَ إِلَى جَارِكَ ‏"‏ ‏.‏ فَغَضِبَ الأَنْصَارِيُّ فَقَالَ يَا رَسُولَ اللَّهِ أَنْ كَانَ ابْنَ عَمَّتِكَ فَتَلَوَّنَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ يَا زُبَيْرُ اسْقِ ثُمَّ احْبِسِ الْمَاءَ حَتَّى يَرْجِعَ إِلَى الْجَدْرِ ‏"‏ ‏.‏ فَقَالَ الزُّبَيْرُ إِنِّي أَحْسَبُ أَنَّ هَذِهِ الآيَةَ نَزَلَتْ فِي ذَلِكَ ‏\{‏ فَلاَ وَرَبِّكَ لاَ يُؤْمِنُونَ ‏\}‏ الآيَةَ ‏.‏\hadithno{5416}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Urwah that 'Abdullah bin Az-Zubair narrated to him that:A man among the Ansar disputed with Az-Zubair concerning a stream in Al-Harrah from which they both used to water their date palm trees. The Ansari said: "Let the water flow," but he (Az-Zubair) refused. They brought their dispute to the Messenger of Allah [SAW]. The Messenger of Allah [SAW] said: "Irrigate (your land), O Zubair, then let the water flow to your neighbor." The Ansari became angry and said: "O Messenger of Allah, is it because he is your cousin?" The face of the Messenger of Allah [SAW] changed color (because of anger) and he said: "O Zubair, irrigate (your land) then block the water until it flows back to the walls." Az-Zubair said: "I think that this Verse was revealed concerning this matter: 'But no, by your Lord, they can have no faith}}
\hadithdefcmd{nasai}{5417}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ زَوْجَ، بَرِيرَةَ كَانَ عَبْدًا يُقَالُ لَهُ مُغِيثٌ كَأَنِّي أَنْظُرُ إِلَيْهِ يَطُوفُ خَلْفَهَا يَبْكِي وَدُمُوعُهُ تَسِيلُ عَلَى لِحْيَتِهِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم لِلْعَبَّاسِ ‏"‏ يَا عَبَّاسُ أَلاَ تَعْجَبُ مِنْ حُبِّ مُغِيثٍ بَرِيرَةَ وَمِنْ بُغْضِ بَرِيرَةَ مُغِيثًا ‏"‏ ‏.‏ فَقَالَ لَهَا النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَوْ رَاجَعْتِيهِ فَإِنَّهُ أَبُو وَلَدِكِ ‏"‏ ‏.‏ قَالَتْ يَا رَسُولَ اللَّهِ أَتَأْمُرُنِي ‏.‏ قَالَ ‏"‏ إِنَّمَا أَنَا شَفِيعٌ ‏"‏ ‏.‏ قَالَتْ فَلاَ حَاجَةَ لِي فِيهِ ‏.‏\hadithno{5417}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn 'Abbas that:The husband of Barirah was a slave called Mughith. It is as if I can see him walking behind her weeping, with the tears running down onto his beard. The Prophet [SAW] said to Al-'Abbas: "O 'Abbas, are you not amazed by the love of Mughith for Barirah and the hatred of Barirah for Mughith?" The Messenger of Allah [SAW] said to her: "Why don't you take him back, for he is the father of your child?" She said: "O Messenger of Allah, are you commanding me (to do so)?" He said: "I am just interceding." She said: "I have no need of him}}
\hadithdefcmd{nasai}{5418}{أَخْبَرَنَا عَبْدُ الأَعْلَى بْنُ وَاصِلِ بْنِ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا مُحَاضِرُ بْنُ الْمُوَرِّعِ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ أَعْتَقَ رَجُلٌ مِنَ الأَنْصَارِ غُلاَمًا لَهُ عَنْ دُبُرٍ وَكَانَ مُحْتَاجًا وَكَانَ عَلَيْهِ دَيْنٌ فَبَاعَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِثَمَانِمِائَةِ دِرْهَمٍ فَأَعْطَاهُ فَقَالَ ‏ "‏ اقْضِ دَيْنَكَ وَأَنْفِقْ عَلَى عِيَالِكَ ‏"‏ ‏.‏\hadithno{5418}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"A man among the Ansar stated that his salve was to be set free after he died; he was in need, and he owed a debt. The Messenger of Allah [SAW] sold him (the slave) for eight hundred Dirhams, and he gave (the money) to him and said: 'Pay off your debt and spend on your dependents}}
\hadithdefcmd{nasai}{5419}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا الْعَلاَءُ، عَنْ مَعْبَدِ بْنِ كَعْبٍ، عَنْ أَخِيهِ عَبْدِ اللَّهِ بْنِ كَعْبٍ، عَنْ أَبِي أُمَامَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنِ اقْتَطَعَ حَقَّ امْرِئٍ مُسْلِمٍ بِيَمِينِهِ فَقَدْ أَوْجَبَ اللَّهُ لَهُ النَّارَ وَحَرَّمَ عَلَيْهِ الْجَنَّةَ ‏"‏ ‏.‏ فَقَالَ لَهُ رَجُلٌ وَإِنْ كَانَ شَيْئًا يَسِيرًا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَإِنْ كَانَ قَضِيبًا مِنْ أَرَاكٍ ‏"‏ ‏.‏\hadithno{5419}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Umamah that :The Messenger of Allah [SAW] said: "Whoever seizes the wealth of a Muslim unlawfully by means of his (false) oath, Allah makes the Fire required for him, Paradise unlawful for him." A man said to him: "O Messenger of Allah, even if it is something small?" He said: "Even if it is a twig of an Arak tree}}
\hadithdefcmd{nasai}{5420}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا وَكِيعٌ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتْ هِنْدٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أَبَا سُفْيَانَ رَجُلٌ شَحِيحٌ وَلاَ يُنْفِقُ عَلَىَّ وَوَلَدِي مَا يَكْفِينِي أَفَآخُذُ مِنْ مَالِهِ وَلاَ يَشْعُرُ قَالَ ‏ "‏ خُذِي مَا يَكْفِيكِ وَوَلَدَكِ بِالْمَعْرُوفِ ‏"‏ ‏.‏\hadithno{5420}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"Hind came to the Messenger of Allah [SAW] and said : 'O Messenger of Allah, Abu Sufyan is a stingy man who does not spend enough on my child and I. Can I take from his wealth without him realizing?' He said: 'Take what is sufficient for you and your child on a reasonable basis}}
\hadithdefcmd{nasai}{5421}{أَخْبَرَنَا الْحُسَيْنُ بْنُ مَنْصُورِ بْنِ جَعْفَرٍ، قَالَ حَدَّثَنَا مُبَشِّرُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ حُسَيْنٍ، عَنْ جَعْفَرِ بْنِ إِيَاسٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، - وَكَانَ عَامِلاً عَلَى سِجِسْتَانَ - قَالَ كَتَبَ إِلَىَّ أَبُو بَكْرَةَ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَقْضِيَنَّ أَحَدٌ فِي قَضَاءٍ بِقَضَاءَيْنِ وَلاَ يَقْضِي أَحَدٌ بَيْنَ خَصْمَيْنِ وَهُوَ غَضْبَانُ ‏"‏ ‏.‏\hadithno{5421}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah bin Abi Bakrah, who was a governor in Sijistan, said:"Abu Bakrah wrote to me, saying: 'I heard the Messenger of Allah [SAW] say: No one should pass two judgments on one issue, and no one should pass judgment between two disputing parties while he is angry}}
\hadithdefcmd{nasai}{5422}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّكُمْ تَخْتَصِمُونَ إِلَىَّ وَإِنَّمَا أَنَا بَشَرٌ وَلَعَلَّ بَعْضَكُمْ أَلْحَنُ بِحُجَّتِهِ مِنْ بَعْضٍ فَإِنَّمَا أَقْضِي بَيْنَكُمَا عَلَى نَحْوِ مَا أَسْمَعُ فَمَنْ قَضَيْتُ لَهُ مِنْ حَقِّ أَخِيهِ شَيْئًا فَإِنَّمَا أَقْطَعُ لَهُ قِطْعَةً مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{5422}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Umm Salamah said:"The Messenger of Allah [SAW] said: 'You refer your disputes to me, but I am only human. And some of you may be more eloquent in arguing their case than others, and I may pass judgment on the basis of what I hear. If I pass judgment in favor of one of you against his brother's rights, then it is a piece of the fire that I am giving him}}
\hadithdefcmd{nasai}{5423}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي ابْنُ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَبْغَضَ الرِّجَالِ إِلَى اللَّهِ الأَلَدُّ الْخَصِمُ ‏"‏ ‏.‏\hadithno{5423}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah [SAW] said: 'The most hated of men to Allah is the most quarrelsome of opponents}}
\hadithdefcmd{nasai}{5424}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، عَنْ أَبِي مُوسَى، أَنَّ رَجُلَيْنِ، اخْتَصَمَا إِلَى النَّبِيِّ صلى الله عليه وسلم فِي دَابَّةٍ لَيْسَ لِوَاحِدٍ مِنْهُمَا بَيِّنَةٌ فَقَضَى بِهَا بَيْنَهُمَا نِصْفَيْنِ ‏.‏\hadithno{5424}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Musa:That two men referred a dispute to the Prophet [SAW] concerning an animal, and neither of them had any evidence, so he ruled that it be shared equally between them}}
\hadithdefcmd{nasai}{5425}{أَخْبَرَنَا عَلِيُّ بْنُ سَعِيدِ بْنِ مَسْرُوقٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي زَائِدَةَ، عَنْ نَافِعِ بْنِ عُمَرَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، قَالَ كَانَتْ جَارِيَتَانِ تَخْرُزَانِ بِالطَّائِفِ فَخَرَجَتْ إِحْدَاهُمَا وَيَدُهَا تَدْمَى فَزَعَمَتْ أَنَّ صَاحِبَتَهَا أَصَابَتْهَا وَأَنْكَرَتِ الأُخْرَى فَكَتَبْتُ إِلَى ابْنِ عَبَّاسٍ فِي ذَلِكَ فَكَتَبَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى أَنَّ الْيَمِينَ عَلَى الْمُدَّعَى عَلَيْهِ وَلَوْ أَنَّ النَّاسَ أُعْطُوا بِدَعْوَاهُمْ لاَدَّعَى نَاسٌ أَمْوَالَ نَاسٍ وَدِمَاءَهُمْ فَادْعُهَا وَاتْلُ عَلَيْهَا هَذِهِ الآيَةَ ‏\{‏ إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً أُولَئِكَ لاَ خَلاَقَ لَهُمْ فِي الآخِرَةِ ‏\}‏ حَتَّى خَتَمَ الآيَةَ فَدَعَوْتُهَا فَتَلَوْتُ عَلَيْهَا فَاعْتَرَفَتْ بِذَلِكَ فَسَرَّهُ ‏.‏\hadithno{5425}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Nafi' bin 'Umar, that Ibn Abi Mulaikah said:"There were two female neighbors who used to do leatherwork (with an awl) in At-Ta'if. One of them came out with her hand bleeding and claimed that her companion had injured her, but the other one denied it. I wrote to Ibn 'Abbas concerning that. He wrote, (saying) that the Messenger of Allah [SAW] ruled that the person against whom the claim was made should swear an oath. For if people were to be given what they claimed was theirs, then people would make claims against the wealth and blood of others." So he called her and recited this Verse to her: "Verily, those who purchase a small gain at the cost of Allah's Covenant and their oaths, they shall have no portion in the Hereafter..." until the end of the Verse. He called her and recited that to her, and she confessed to that. News of that reached him and he was happy}}
\hadithdefcmd{nasai}{5426}{أَخْبَرَنَا سَوَّارُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مَرْحُومُ بْنُ عَبْدِ الْعَزِيزِ، عَنْ أَبِي نَعَامَةَ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ مُعَاوِيَةُ رَضِيَ اللَّهُ عَنْهُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ عَلَى حَلْقَةٍ - يَعْنِي مِنْ أَصْحَابِهِ - فَقَالَ ‏"‏ مَا أَجْلَسَكُمْ ‏"‏ ‏.‏ قَالُوا جَلَسْنَا نَدْعُو اللَّهَ وَنَحْمَدُهُ عَلَى مَا هَدَانَا لِدِينِهِ وَمَنَّ عَلَيْنَا بِكَ ‏.‏ قَالَ ‏"‏ آللَّهِ مَا أَجْلَسَكُمْ إِلاَّ ذَلِكَ ‏"‏ ‏.‏ قَالُوا آللَّهِ مَا أَجْلَسَنَا إِلاَّ ذَلِكَ ‏.‏ قَالَ ‏"‏ أَمَا إِنِّي لَمْ أَسْتَحْلِفْكُمْ تُهَمَةً لَكُمْ وَإِنَّمَا أَتَانِي جِبْرِيلُ عَلَيْهِ السَّلاَمُ فَأَخْبَرَنِي أَنَّ اللَّهَ عَزَّ وَجَلَّ يُبَاهِي بِكُمُ الْمَلاَئِكَةَ ‏"‏ ‏.‏\hadithno{5426}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"Mu'awiyah, (may Allah be pleased with him,) said: 'The Messenger of Allah [SAW] went out to a circle - meaning, of his Companions - and said: 'What are you doing?' They said: 'We have come together to pray to Allah and praise Him for guiding us to His religion, and blessing us with you.' He said: 'I ask you, by Allah, is that the only reason?' They said: 'By Allah, we have not come together for any other reason.' He said: 'I am not asking you to swear to an oath because of any suspicion; rather Jibril came to me and told me that Allah, the Mighty and Sublime, is boasting of you to the angels}}
\hadithdefcmd{nasai}{5427}{أَخْبَرَنَا أَحْمَدُ بْنُ حَفْصٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رَأَى عِيسَى ابْنُ مَرْيَمَ عَلَيْهِ السَّلاَمُ رَجُلاً يَسْرِقُ فَقَالَ لَهُ أَسَرَقْتَ قَالَ لاَ وَاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ ‏.‏ قَالَ عِيسَى عَلَيْهِ السَّلاَمُ آمَنْتُ بِاللَّهِ وَكَذَّبْتُ بَصَرِي ‏"‏ ‏.‏\hadithno{5427}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said: 'Isa bin Mariam, peace be upon him, saw a man stealing, and said to him: Are you stealing? He said: No, by Allah besides Whom there is no other God! 'Isa, peace be upon him, said: I believe in Allah and I disbelieve my eyes}}
